@@ -9,8 +9,8 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 our $AUTHORITY = 'cpan:RSRCHBOY';
-# git description: 0.068-7-gaaa7bb9
-$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.069';
+# git description: 0.069-10-g18b05e5
+$Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.070';
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
 
@@ -49,16 +49,27 @@ sub _build_is_app     { $_[0]->payload->{cat_app} || $_[0]->payload->{app} }
 sub _build_is_private { $_[0]->payload->{private}                          }
 sub _build_rapid_dev  { $_[0]->payload->{rapid_dev}                        }
 
-my $_d = sub { my $key = shift; sub { shift->payload->{$key} } };
-has $_ => (is => 'lazy', isa => 'Bool')
-    for qw{ sign tweet github install_on_release };
-has "is_$_" => (is => 'lazy', isa => 'Bool', builder => $_d->($_))
-    for qw{ task };
+{
+    my $_builder_for = sub { my $key = shift; sub { shift->payload->{$key} // 1 } };
 
-sub _build_sign               { shift->payload->{sign}               // 1 }
-sub _build_tweet              { shift->payload->{tweet}              // 1 }
-sub _build_github             { shift->payload->{github}             // 1 }
-sub _build_install_on_release { shift->payload->{install_on_release} // 1 }
+    has $_ => (
+        traits  => ['Bool'],
+        is      => 'lazy',
+        isa     => 'Bool',
+        builder => $_builder_for->($_),
+        handles => { "no_$_" => 'not' },
+    )
+    for qw{ sign tweet github install_on_release }
+    ;
+}
+
+has is_task => (
+    traits  => ['Bool'],
+    is      => 'lazy',
+    isa     => 'Bool',
+    builder => sub { shift->payload->{task} },
+    handles => { is_not_task => 'not' },
+);
 
 has _copy_from_build => (
     is      => 'lazy',
@@ -136,29 +147,24 @@ sub release_plugins {
                 'origin refs/heads/release/cpan:refs/heads/release/cpan',
             ],
         }],
-    );
 
-    push @plugins, 'UploadToCPAN'
-        unless $self->is_private;
+        $self->no_tweet ? () : [
+            Twitter => {
+                hash_tags => '#perl #cpan',
+                # TODO: remove the next line when resolved:
+                # https://github.com/dagolden/dist-zilla-plugin-twitter/issues/11
+                tweet_url => 'https://metacpan.org/release/{{$AUTHOR_UC}}/{{$DIST}}-{{$VERSION}}{{$TRIAL}}/',
+            },
+        ],
 
-    push @plugins, 'Signature',
-        if $self->sign;
-    push @plugins, [
-        Twitter => {
-            hash_tags => '#perl #cpan',
-            # TODO: remove the next line when resolved:
-            # https://github.com/dagolden/dist-zilla-plugin-twitter/issues/11
-            tweet_url => 'https://metacpan.org/release/{{$AUTHOR_UC}}/{{$DIST}}-{{$VERSION}}{{$TRIAL}}/',
-        } ] if $self->tweet;
-    push @plugins, [ InstallRelease => { install_command => 'cpanm .' } ]
-        if $self->install_on_release;
-    push @plugins, [ 'GitHub::Update' => { metacpan  => 1 } ]
-        if $self->github;
+        $self->is_private            ? () : 'UploadToCPAN',
+        $self->no_sign               ? () : 'Signature',
+        $self->no_install_on_release ? () : [ InstallRelease   => { install_command => 'cpanm .' } ],
+        $self->no_github             ? () : [ 'GitHub::Update' => { metacpan        => 1         } ],
 
-    push @plugins,
         [ ArchiveRelease => { directory => 'releases' } ],
         'ConfirmRelease',
-        ;
+    );
 
     return @plugins;
 }
@@ -182,7 +188,6 @@ sub author_tests {
             NoSmartCommentsTests
             Test::Pod::LinkCheck
             RunExtraTests
-            CheckExtraTests
         },
         [ 'Test::MinimumVersion' => { max_target_perl => '5.008008' } ],
     );
@@ -197,6 +202,8 @@ sub meta_provider_plugins {
         qw{ MetaConfig MetaJSON MetaYAML },
         [ MetaNoIndex => { directory => [ qw{ corpus t } ] } ],
         'MetaProvides::Package',
+
+        'MetaData::BuiltWith',
     );
 
     if ($self->github) {
@@ -243,7 +250,7 @@ sub configure {
     $self->add_bundle('Git::CheckFor');
 
     $self->add_plugins(
-        [ GatherDir => { exclude_filename => $self->_copy_from_build } ],
+        [ 'Git::GatherDir' => { exclude_filename => $self->_copy_from_build } ],
         [
             PromptIfStale => {
                 phase   => 'build',
@@ -367,15 +374,13 @@ __END__
 
 =for :stopwords Chris Weyl Bowers Neil Romanov Sergey
 
-=for :stopwords Wishlist flattr flattr'ed gittip gittip'ed
-
 =head1 NAME
 
 Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.069 of Dist::Zilla::PluginBundle::RSRCHBOY - released October 10, 2016 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.070 of Dist::Zilla::PluginBundle::RSRCHBOY - released February 27, 2017 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -385,8 +390,13 @@ This document describes version 0.069 of Dist::Zilla::PluginBundle::RSRCHBOY - r
 =head1 DESCRIPTION
 
 This is RSRCHBOY's current L<Dist::Zilla> C<dist.ini> config for his packages.
-He's still figuring this all out, so it's probably wise to not depend on
-this being too terribly consistent/sane until the version gets to 1.
+He's still figuring this all out.  It's like vim, you never really know all
+the things.
+
+If you'd like to see what this does without digging into the guts, I recommend
+you install the most excellent L<Dist::Zilla::App::Command::dumpphases>
+package.  This will give you a new dzil command, allowing you to see a
+sensible dump of what plugins are going to be used, etc.
 
 =head1 METHODS
 
@@ -462,7 +472,7 @@ Please see those modules/websites for more information related to this module.
 
 =item *
 
-L<Dist::Zilla::Role::PluginBundle::Easy|Dist::Zilla::Role::PluginBundle::Easy>
+L<Dist::Zilla::App::Command::dumpphases|Dist::Zilla::App::Command::dumpphases>
 
 =item *
 
@@ -491,25 +501,6 @@ feature.
 
 Chris Weyl <cweyl@alumni.drew.edu>
 
-=head2 I'm a material boy in a material world
-
-=begin html
-
-<a href="https://gratipay.com/RsrchBoy/"><img src="http://img.shields.io/gratipay/RsrchBoy.svg" /></a>
-<a href="http://bit.ly/rsrchboys-wishlist"><img src="http://wps.io/wp-content/uploads/2014/05/amazon_wishlist.resized.png" /></a>
-<a href="https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-rsrchboy&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-RSRCHBOY&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-RSRCHBOY%20in%20the%20CPAN%22"><img src="http://api.flattr.com/button/flattr-badge-large.png" /></a>
-
-=end html
-
-Please note B<I do not expect to be gittip'ed or flattr'ed for this work>,
-rather B<it is simply a very pleasant surprise>. I largely create and release
-works like this because I need them or I find it enjoyable; however, don't let
-that stop you if you feel like it ;)
-
-L<Flattr|https://flattr.com/submit/auto?user_id=RsrchBoy&url=https%3A%2F%2Fgithub.com%2FRsrchBoy%2Fdist-zilla-pluginbundle-rsrchboy&title=RsrchBoy's%20CPAN%20Dist-Zilla-PluginBundle-RSRCHBOY&tags=%22RsrchBoy's%20Dist-Zilla-PluginBundle-RSRCHBOY%20in%20the%20CPAN%22>,
-L<Gratipay|https://gratipay.com/RsrchBoy/>, or indulge my
-L<Amazon Wishlist|http://bit.ly/rsrchboys-wishlist>...  If and *only* if you so desire.
-
 =head1 CONTRIBUTORS
 
 =for stopwords Neil Bowers Sergey Romanov
